blueye.sdk.battery - Blueye SDK

Skip to content

# blueye.sdk.battery

## `` battery

    Battery(parent_drone: Drone)

Contains the battery related functions.

Parameters:

- `parent_drone` (`Drone`) –

  The parent drone instance.

Source code in `blueye/sdk/battery.py`

    15
    16
    17
    18
    19
    20
    def __init__(self, parent_drone: Drone):
        """Initialize the Battery class.

        Args:
            parent_drone (Drone): The parent drone instance."""
        self._parent_drone = parent_drone

#### `` state_of_charge `property`

    state_of_charge: Optional[float]

Get the battery state of charge.

Returns:

- `Optional[float]` –

  Current state of charge of the drone battery (0..1).